﻿using C1.C1Schedule;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace Scheduler.GoogleCalendarSyncer
{
    /// <summary>
    /// Adpater for providing appointments from web-based calendars
    /// </summary>
    public interface IAppointmentAdapter
    {
        /// <summary>
        /// Fires before starting of syncing operation.
        /// </summary>
        event EventHandler<SyncEventArgs> SyncStarting;
        /// <summary>
        /// Fires when syncing is finished.
        /// </summary>
        event EventHandler SyncFinished;
        /// <summary>
        /// Fires when syncing fails.
        /// </summary>
        event EventHandler SyncFailed;


        /// <summary>
        /// Gets events based on parameters criteria.
        /// </summary>
        /// <param name="requestParameters">    
        /// </param>
        /// <returns></returns>
        AppointmentsResponse GetAppointments(RequestParameters requestParameters);

        /// <summary>
        /// Add appointment to web calendar
        /// </summary>
        /// <param name="appointment"></param>
        void AddAppointment(Appointment appointment);

        /// <summary>
        /// Delete appointment from web calendar.
        /// </summary>
        /// <param name="appointment"></param>
        void DeleteAppointment(Appointment appointment);

        /// <summary>
        /// Update an edited appointment to web calendar. This method only uses auto sync mode.
        /// </summary>
        /// <param name="appointment"></param>
        void UpdateAppointment(Appointment appointment);


        /// <summary>
        /// Syncs all the added and deleted appointments with web calendar.
        /// </summary>
        Task Sync();
    }
}
