﻿using System;
using System.ComponentModel;

namespace Scheduler.GoogleCalendarSyncer
{
    /// <summary>
    /// Class containing parameters for creating query for fetching appointments.
    /// </summary>
    public class RequestParameters
    {
        private int _maxResults = 250;
        /// <summary>
        ///    Events having start date after or on this date.
        /// </summary>
        public DateTime MinDate { get; set; }
        /// <summary>
        ///    Events having end date before or on this date.
        /// </summary>
        public DateTime MaxDate { get; set; }
        /// <summary>
        ///    Whether deleted events need to be included.
        /// </summary>
        [DefaultValue(false)]
        public bool ShowDeleted { get; set; } = false;
        /// <summary>
        ///    Maximum number of events returned on one result page. The number of events in
        ///    the resulting page may be less than this value, or none at all, even if there
        ///    are more events matching the query. Incomplete pages can be detected by a non-empty
        ///    nextPageToken field in the response. By default the value is 250 events. The
        ///    page size can never be larger than 2500 events. Optional.
        /// </summary>    
        [DefaultValue(250)]
        public int MaxResults
        {
            get
            {
                return _maxResults;
            }
            set
            {
                if (value < 1)
                    _maxResults = 250;
                else
                    _maxResults = value;
            }
        }
        /// <summary>
        ///    Whether to expand recurring events into instances and only return single one-off
        ///    events and instances of recurring events, but not the underlying recurring events
        ///    themselves. Optional. The default is False.
        /// </summary>
        [DefaultValue(false)]
        public bool SingleEvents { get; set; } = false;
        /// <summary>
        /// Appointment fetching order.
        /// </summary>
        public OrderBy OrderBy { get; set; }
        /// <summary>
        ///     Token specifying which result page to return. Optional.
        /// </summary>
        public string PageToken { get; set; }
    }
}
