﻿using C1.C1Schedule;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;

namespace Scheduler.GoogleCalendarSyncer
{
    /// <summary>
    /// Syncing event args
    /// </summary>
    public class SyncEventArgs : EventArgs
    {
        /// <summary>
        /// Appointments added in manual sync mode.
        /// </summary>
        public ReadOnlyCollection<Appointment> AddedAppointments { get; private set; }
        /// <summary>
        /// Appointments deleted in manual sync mode.
        /// </summary>
        public ReadOnlyCollection<Appointment> DeletedAppointments { get; private set; }
        /// <summary>
        /// Gets or sets whether to cancel the syncing process or not.
        /// </summary>
        public bool Cancel { get; set; } = false;

        /// <summary>
        /// 
        /// </summary>
        /// <param name="added"></param>
        /// <param name="deleted"></param>
        public SyncEventArgs(List<Appointment> added, List<Appointment> deleted)
        {
            if(added == null)
                AddedAppointments = new ReadOnlyCollection<Appointment>(new List<Appointment>());
            else
                AddedAppointments = added.AsReadOnly();

            if (deleted == null)
                DeletedAppointments = new ReadOnlyCollection<Appointment>(new List<Appointment>());
            else
                DeletedAppointments = deleted.AsReadOnly();
        }
    }
}
