﻿using Scheduler.GoogleCalendarSyncer;
using System;
using System.ComponentModel;
using System.Windows.Controls;

namespace SchedulerWithGoogleCalendar
{
    /// <summary>
    /// Interaction logic for FilterToolbar.xaml
    /// </summary>
    public partial class FilterToolbar : UserControl, INotifyPropertyChanged
    {
        public event PropertyChangedEventHandler PropertyChanged;

        private DateTime _minDate;
        private DateTime _maxDate;
        private int _maxResults;
        private OrderBy _orderBy;
        private bool _singleEvents;
        private bool _manualSync;
        private bool _showDeleted;

        public DateTime MinDate
        {
            get
            {
                return _minDate;
            }
            set
            {
                _minDate = value;
                OnPropertyChanged(nameof(MinDate));
            }
        }

        public DateTime MaxDate
        {
            get
            {
                return _maxDate;
            }
            set
            {
                _maxDate = value;
                OnPropertyChanged(nameof(MaxDate));
            }
        }

        public int MaxResults
        {
            get
            {
                return _maxResults;
            }
            set
            {
                if(value <= 500 || value > 0)
                {
                    _maxResults = value;
                    
                }
                else
                {
                    _maxResults = 250;
                }
                OnPropertyChanged(nameof(MaxResults));
            }
        }

        public OrderBy OrderBy
        {
            get
            {
                return _orderBy;
            }
            set
            {
                _orderBy = value;
                OnPropertyChanged(nameof(OrderBy));
            }
        }

        public bool SingleEvents
        {
            get
            {
                return _singleEvents;
            }
            set
            {
                _singleEvents = value;
                OnPropertyChanged(nameof(SingleEvents));
            }
        }

        public bool ManualSync
        {
            get
            {
                return _manualSync;
            }
            set
            {
                _manualSync = value;
                OnPropertyChanged(nameof(ManualSync));
            }
        }

        public bool ShowDeleted
        {
            get
            {
                return _showDeleted;
            }
            set
            {
                _showDeleted = value;
                OnPropertyChanged(nameof(ShowDeleted));
            }
        }

        public FilterToolbar()
        {
            InitializeComponent();
            InitializeParameters();
            DataContext = this;
        }

        private void InitializeParameters()
        {
            var today = DateTime.Today;
            _minDate = today.AddDays(-30);
            _maxDate = today;
            _showDeleted = false;
            _manualSync = false;
            _singleEvents = true;
            _orderBy = OrderBy.StartTime;
            _maxResults = 250;
        }

        public RequestParameters GetRequestParameters()
        {
            return new RequestParameters()
            {
                MinDate = MinDate,
                MaxDate = MaxDate,
                OrderBy = this.OrderBy,
                ShowDeleted = ShowDeleted,
                MaxResults = MaxResults,
                SingleEvents = SingleEvents
            };
        }

        public void OnPropertyChanged(string propertyName)
        {
            PropertyChanged?.Invoke(this, new PropertyChangedEventArgs(propertyName));
        }
    }
}
