﻿using C1.WPF.Schedule;
using System.Windows;
using System.Windows.Controls;

namespace SchedulerWithGoogleCalendar
{
    /// <summary>
    /// Interaction logic for ViewModeToolbar.xaml
    /// </summary>
    public partial class ViewModeToolbar : UserControl
    {
        public ViewType ViewType
        {
            get { return (ViewType)GetValue(ViewTypeProperty); }
            set { SetValue(ViewTypeProperty, value); }
        }

        public static readonly DependencyProperty ViewTypeProperty =
            DependencyProperty.Register("ViewType", typeof(ViewType), typeof(ViewModeToolbar), new PropertyMetadata(ViewType.Month, new PropertyChangedCallback(SetViewType)));

        public ViewModeToolbar()
        {
            InitializeComponent();
        }

        private void ViewTypeSelected(object sender, RoutedEventArgs e)
        {
            var button = sender as RadioButton;

            switch(button.Content)
            {
                case "Day":
                    ViewType = ViewType.Day;
                    break;

                case "Week":
                    ViewType = ViewType.Week;
                    break;

                case "Working Week":
                    ViewType = ViewType.WorkingWeek;
                    break;

                case "Month":
                    ViewType = ViewType.Month;
                    break;

                case "TimeLine":
                    ViewType = ViewType.TimeLine;
                    break;
            }
        }

        private static void SetViewType(DependencyObject d, DependencyPropertyChangedEventArgs e)
        {
            ViewModeToolbar toolbar = d as ViewModeToolbar;
            toolbar.SetViewType((ViewType)e.NewValue);
        }

        private void SetViewType(ViewType viewType)
        {
            switch (viewType)
            {
                case ViewType.Day:
                    btnDay.IsChecked = true;
                    break;

                case ViewType.Week:
                    btnWeek.IsChecked = true;
                    break;

                case ViewType.Month:
                    btnMonth.IsChecked = true;
                    break;

                case ViewType.WorkingWeek:
                    btnWorkWeek.IsChecked = true;
                    break;

                case ViewType.TimeLine:
                    btnTimeLine.IsChecked = true;
                    break;
            }
        }
    }
}
